BitcoinRpcErrorExt

Trait BitcoinRpcErrorExt 

pub trait BitcoinRpcErrorExt: Borrow<Error> {
    // Provided methods
    fn is_not_found(&self) -> bool { ... }
    fn is_in_utxo_set(&self) -> bool { ... }
    fn is_already_in_mempool(&self) -> bool { ... }
}

Provided Methods

fn is_not_found(&self) -> bool

Whether this error indicates that the tx was not found.

fn is_in_utxo_set(&self) -> bool

Whether this error indicates that the tx is already in the utxo set.

fn is_already_in_mempool(&self) -> bool

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors